Clazz.declarePackage("javajs.api");
Clazz.load(["java.util.zip.ZipInputStream", "javajs.api.ZInputStream"], "javajs.api.GenericZipInputStream", null, function(){
var c$ = Clazz.declareType(javajs.api, "GenericZipInputStream", java.util.zip.ZipInputStream, javajs.api.ZInputStream);
});
;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
